#
# spec file for package apache2-mod_auth_kerb
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           apache2-mod_auth_kerb
Version:        5.4
Release:        lp151.3.3.1
Summary:        Kerberos Module for Apache
License:        BSD-3-Clause and MIT and Apache-2.0
Group:          Productivity/Networking/Web/Servers
Url:            http://modauthkerb.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/modauthkerb/mod_auth_kerb-%{version}.tar.gz
Patch1:         mod_auth_kerb-5.1-defproblem.dif
Patch2:         mod_auth_kerb-fix_warnings.patch
Patch3:         mod_auth_kerb-5.4-configure.patch
Patch4:         mod_auth_kerb-cache_auth.patch
Patch5:         mod_auth_kerb.apache22+.patch
Patch6:         mod_auth_kerb-5.4-auth_segfault.patch
Patch101:       0101-mod_auth_kerb-5.4-s4u2proxy.patch
Patch102:       0102-mod_auth_kerb-5.4-httpd24.patch
Patch103:       0103-mod_auth_kerb-5.4-delegation.patch
Patch104:       0104-mod_auth_kerb-5.4-longuser.patch
Patch105:       0105-mod_auth_kerb-5.4-handle-continue.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  krb5-devel
BuildRequires:  libtool
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mod_auth_kerb is an Apache module designed to provide Kerberos authentication to
the Apache web server. Using the Basic Auth mechanism, it retrieves a
username/password pair from the browser and checks them against a Kerberos
server as set up by your particular organization. The module also supports the
Negotiate authentication method, which performs full Kerberos authentication
based on ticket exchanges, and does not require users to insert their passwords
to the browser.

%prep
%setup -q -n "mod_auth_kerb-%{version}"
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1

%build
autoreconf -fiv

# Necessary when building with apr 1.2.x instead of the apr that comes with httpd
export CPPFLAGS="-I%{_includedir}/apr-1"
%configure --with-krb4=no \
           --with-krb5 \
           --with-apache="%{_prefix}" || { cat "config.log"; exit 1; }

make %{?_smp_mflags}

%install
install -D -m0755 src/.libs/mod_auth_kerb.so "%{buildroot}/%{apache_libexecdir}/mod_auth_kerb.so"

%check
set +x
%apache_test_module_load -m auth_kerb
set -x

%files
%defattr(-,root,root)
%doc LICENSE README
%dir %{apache_libexecdir}
%{apache_libexecdir}/mod_auth_kerb.so

%changelog
* Wed Jul 24 2019 Kristyna Streitova <kstreitova@suse.com>
- add mod_auth_kerb-5.4-auth_segfault.patch to fix a segmentation
  fault in function authenticate_user_krb5pwd() when credentials
  are supplied using basic authentication [bsc#1142545]
* Fri Oct  2 2015 pgajdos@suse.com
- fix build for 11sp3 (add BuildRoot:)
* Wed Sep 23 2015 pgajdos@suse.com
- test module with %%apache_test_module_load
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Wed Jun  3 2015 hguo@suse.com
- Clean up of spec file:
  * Fix unrecognised license name (Apache 2.0).
  * Remove build dependencies and macros for building on unsupported SUSE distros.
  * Remove expired macro "debug_package".
  * Fix URL link of the package.
  * Remove unnecessary "INSTALL" document file from file list.
* Tue May 26 2015 kstreitova@suse.com
- add new licenses:
  * MIT - for mit-internals.h file
  * ASL 2.0 - for 0101-mod_auth_kerb-5.4-s4u2proxy.patch
* Mon May 11 2015 hguo@suse.com
- Introduce upstream patches:
  * Support s4u2proxy operation.
  * Fix an issue that causes loss of delegation after first request on the connection.
  * Fix an issue that causes HTTP 500 error when user account name is longer than Kerberos principal name.
  * Consider authentication request successful when GSS_S_CONTINUE_NEEDED (multiple-exchange-request) is encountered.
  The existing patch for Apache2.4 compatibility has been re-aligned with the introduction of new patches.
* Fri Oct 31 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Fri Mar 28 2014 draht@suse.de
- sles12 submission:
  * mod_auth_kerb.apache22.patch -> mod_auth_kerb.apache22+.patch
    make apache 2.2 modifications unconditional, as they are
    required by apache 2.4, too.
    This immediately means that compiling this package against
    apache 2.0 would not work.
  * rework mod_auth_kerb-5.4-apache24.patch into
    mod_auth_kerb-api_changes_apache24.patch: adaption to apache
    2.4 API, in particular logging and remote IP reference struct
    members.
* Sat Apr  6 2013 mc@suse.com
- add support for apache 2.4
  mod_auth_kerb-5.4-apache24.patch
  http://sourceforge.net/tracker/?func=detail&aid=3521787&group_id=51775&atid=464526
- new format for License
* Thu Jul 12 2012 draht@suse.de
- preparation of the package for submission against sle11-sp1,
  review of source and patches/changes, compilation warnings,
  licence and packaging. This is (FATE#313165) (ECO-FATE#313165)
  and [bnc#771265].
* Fri Jul 17 2009 pascal.bleser@opensuse.org
- add mod_auth_kerb.apache22.patch that adds Apache 2.2 authn
  provider support (authn_kerberos):
  https://sourceforge.net/tracker/?func=detail&aid=2782088&group_id=51775&atid=464526
* Fri Jul 17 2009 pascal.bleser@opensuse.org
- add per-connection authentication caching, based on
  https://sourceforge.net/tracker/?func=detail&aid=1891230&group_id=51775&atid=464526
  by <jorgensen@lowtechsolutions.net>, but made it configurable
  through the KrbCacheAuthentication directive (that is disabled
  by default, as it is to be seen as experimental)
* Wed Apr  1 2009 pascal.bleser@opensuse.org
- fixed warning fixing patch that was causing a "undefined symbol:
  cmp_gss_type" error at runtime
* Tue Mar 31 2009 pascal.bleser@opensuse.org
- build against heimdal on SLE 9
- added missing %%changelog in spec file
* Fri Mar 27 2009 pascal.bleser@opensuse.org
- update to 5.4:
  * implemented KrbServiceName Any to deal with multiple keytab
    entries for various browsers
  * implemented KrbLocalUserMapping i.e. to strip @REALM from
    username for further use
  * implemented already_succeeded function to avoid hammering the
    KDC with same auth requests in single connection
  * fixed threading issues
  * improved configure and Makefile scripts (mainly for BSD users)
  * fixed minor issues
- minor spec file style fixes
- added patch to fix compiler warnings
- removed mod_auth_kerb-init_creds_opt.dif, has been merged
  upstream
* Mon Sep 10 2007 mc@suse.de
- add mod_auth_kerb-init_creds_opt.dif
* Tue Dec 19 2006 mc@suse.de
- update to version 5.3
* Tue Sep 19 2006 mc@suse.de
- update to version 5.1
* Wed May 17 2006 mc@suse.de
- initial release
